{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/seqs"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/induceGraph/spoaGFA",
                            "id": "#main/buildGraph/inputGFA"
                        }
                    ],
                    "out": [
                        "#main/buildGraph/odgiGraph"
                    ],
                    "run": "#odgi-build-from-spoa-gfa.cwl",
                    "id": "#main/buildGraph"
                },
                {
                    "in": [
                        {
                            "source": "#main/seqs",
                            "id": "#main/dedup_and_sort_by_quality_and_len/readsFA"
                        }
                    ],
                    "out": [
                        "#main/dedup_and_sort_by_quality_and_len/sortedReadsFA",
                        "#main/dedup_and_sort_by_quality_and_len/dups"
                    ],
                    "run": "#sort_fasta_by_quality_and_len.cwl",
                    "id": "#main/dedup_and_sort_by_quality_and_len"
                },
                {
                    "in": [
                        {
                            "source": "#main/dedup_and_sort_by_quality_and_len/sortedReadsFA",
                            "id": "#main/induceGraph/readsFA"
                        }
                    ],
                    "out": [
                        "#main/induceGraph/spoaGFA"
                    ],
                    "run": "#spoa.cwl",
                    "id": "#main/induceGraph"
                },
                {
                    "in": [
                        {
                            "default": 400,
                            "id": "#main/vizGraph/height"
                        },
                        {
                            "default": 4,
                            "id": "#main/vizGraph/path_height"
                        },
                        {
                            "source": "#main/buildGraph/odgiGraph",
                            "id": "#main/vizGraph/sparse_graph_index"
                        },
                        {
                            "default": 1400,
                            "id": "#main/vizGraph/width"
                        }
                    ],
                    "out": [
                        "#main/vizGraph/graph_image"
                    ],
                    "requirements": [
                        {
                            "ramMin": "$(7 * 1024)",
                            "outdirMin": 10,
                            "class": "ResourceRequirement"
                        }
                    ],
                    "run": "#odgi_viz.cwl",
                    "id": "#main/vizGraph"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/buildGraph/odgiGraph",
                    "id": "#main/odgiGraph"
                },
                {
                    "type": "File",
                    "outputSource": "#main/vizGraph/graph_image",
                    "id": "#main/odgiPNG"
                },
                {
                    "type": "File",
                    "outputSource": "#main/dedup_and_sort_by_quality_and_len/sortedReadsFA",
                    "id": "#main/readsMergeDedupSortedByQualAndLen"
                },
                {
                    "type": "File",
                    "outputSource": "#main/induceGraph/spoaGFA",
                    "id": "#main/spoaGFA"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "id": "#odgi-build-from-spoa-gfa.cwl/inputGFA"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.inputGFA.nameroot).unchop.sorted.odgi"
                    },
                    "id": "#odgi-build-from-spoa-gfa.cwl/odgiGraph"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerImageId": "odgi:2020-12-01",
                    "dockerFile": "FROM debian:buster\nWORKDIR /usr/src/app\nRUN apt-get update && apt-get install --no-install-recommends -y \\\n  ca-certificates \\\n  bash \\\n  cmake \\\n  git \\\n  g++ \\\n  make \\\n  python-dev \\\n  && rm -rf /var/lib/apt/lists/*\nRUN git clone --recursive https://github.com/vgteam/odgi.git && cd odgi && git checkout e14c54b7cec1496c6560dfe160223490c329657f\nRUN cd odgi && cmake -H. -Bbuild && cmake --build build -- -j 3\nFROM debian:buster\nRUN apt-get update && apt-get install -y libgomp1 libatomic1 && rm -rf /var/lib/apt/lists/*\nCOPY --from=0 /usr/src/app/odgi/bin/odgi /usr/local/bin\n",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        {
                            "entry": "$(inputs.inputGFA)",
                            "writable": true
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": "$(7 * 1024)",
                    "outdirMin": "$(Math.ceil((inputs.inputGFA.size/(1024*1024*1024)+1) * 2))",
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "arguments": [
                {
                    "shellQuote": false,
                    "valueFrom": "odgi build -g '$(inputs.inputGFA.path)' -o - | odgi unchop -i - -o - | odgi sort -i - -p s -o $(inputs.inputGFA.nameroot).unchop.sorted.odgi"
                }
            ],
            "id": "#odgi-build-from-spoa-gfa.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "odgi viz",
            "doc": "variation graph visualizations",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerImageId": "odgi:2020-12-01",
                    "dockerFile": "FROM debian:buster\nWORKDIR /usr/src/app\nRUN apt-get update && apt-get install --no-install-recommends -y \\\n  ca-certificates \\\n  bash \\\n  cmake \\\n  git \\\n  g++ \\\n  make \\\n  python-dev \\\n  && rm -rf /var/lib/apt/lists/*\nRUN git clone --recursive https://github.com/vgteam/odgi.git && cd odgi && git checkout e14c54b7cec1496c6560dfe160223490c329657f\nRUN cd odgi && cmake -H. -Bbuild && cmake --build build -- -j 3\nFROM debian:buster\nRUN apt-get update && apt-get install -y libgomp1 libatomic1 && rm -rf /var/lib/apt/lists/*\nCOPY --from=0 /usr/src/app/odgi/bin/odgi /usr/local/bin\n",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": "$(7 * 1024)",
                    "outdirMin": 1,
                    "class": "ResourceRequirement"
                },
                {
                    "packages": [
                        {
                            "version": [
                                "0.4.1"
                            ],
                            "package": "odgi"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "height in pixels of output image",
                    "inputBinding": {
                        "prefix": "--height=",
                        "separate": false
                    },
                    "id": "#odgi_viz.cwl/height"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "path display height",
                    "inputBinding": {
                        "prefix": "--path-height=",
                        "separate": false
                    },
                    "id": "#odgi_viz.cwl/path_height"
                },
                {
                    "type": "File",
                    "id": "#odgi_viz.cwl/sparse_graph_index"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "width in pixels of output image",
                    "inputBinding": {
                        "prefix": "--width=",
                        "separate": false
                    },
                    "id": "#odgi_viz.cwl/width"
                }
            ],
            "arguments": [
                "--idx=$(inputs.sparse_graph_index.path)",
                "--out=$(inputs.sparse_graph_index.nameroot).png"
            ],
            "baseCommand": [
                "odgi",
                "viz"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/image/png",
                    "outputBinding": {
                        "glob": "$(inputs.sparse_graph_index.nameroot).png"
                    },
                    "id": "#odgi_viz.cwl/graph_image"
                }
            ],
            "id": "#odgi_viz.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "python:latest",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 3000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#sort_fasta_by_quality_and_len.cwl/readsFA"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "default": {
                        "class": "File",
                        "location": "https://raw.githubusercontent.com/arvados/czi-pangenome-usecase/25a42bc03a51210bf57f2018692d3852b7fa1188/tools/sort_fasta_by_quality_and_len/sort_fasta_by_quality_and_len.py"
                    },
                    "id": "#sort_fasta_by_quality_and_len.cwl/script"
                }
            ],
            "stdout": "$(inputs.readsFA.nameroot).sorted_by_quality_and_len.fasta",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "dups.txt"
                    },
                    "id": "#sort_fasta_by_quality_and_len.cwl/dups"
                },
                {
                    "type": "File",
                    "id": "#sort_fasta_by_quality_and_len.cwl/sortedReadsFA",
                    "outputBinding": {
                        "glob": "$(inputs.readsFA.nameroot).sorted_by_quality_and_len.fasta"
                    }
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [
                "python"
            ],
            "id": "#sort_fasta_by_quality_and_len.cwl"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "id": "#spoa.cwl/readsFA"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#spoa.cwl/spoaGFA",
                    "outputBinding": {
                        "glob": "$(inputs.readsFA.nameroot).g6.gfa"
                    }
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/spoa:3.4.0--hc9558a2_0",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": "$(15 * 1024)",
                    "outdirMin": "$(Math.ceil(inputs.readsFA.size/(1024*1024*1024) + 20))",
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": "spoa",
            "stdout": "$(inputs.readsFA.nameroot).g6.gfa",
            "arguments": [
                "$(inputs.readsFA)",
                "-G",
                "-g",
                "-6"
            ],
            "id": "#spoa.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
